%define anolis_release 2

Name:           xz
Version:        5.4.7
Release:        %{anolis_release}%{?dist}
Summary:        LZMA compression utilities 

License:        GPLv2+ and Public Domain
URL:            https://tukaani.org/xz
Source0:        https://tukaani.org/%{name}/%{name}-%{version}.tar.xz
Source1:        colorxzgrep.csh
Source2:        colorxzgrep.sh

# These five patches are for CVE-2025-31115
# https://github.com/tukaani-project/xz/commit/bdb788137e1f1d967e0c9d885b859e5b95c1b5bf
Patch0001: 0001-liblzma-mt-dec-fix-a-comment.patch
# https://github.com/tukaani-project/xz/commit/2ce9ab6588a94cbf04a9c174e562ea5feb00cfb3
Patch0002: 0002-liblzma-mt-dec-simplify-by-removing-the-THR_STOP-state.patch
# https://github.com/tukaani-project/xz/commit/9a9c17712bd2a070581d9239692e527a2fe13845
Patch0003: 0003-liblzma-mt-dec-do-not-free-the-input-buffer-too-early-CVE-2025-31115.patch
# https://github.com/tukaani-project/xz/commit/c8bb46c5a16ed02401f4a0b46c74f0f46c1b6434
Patch0004: 0004-liblzma-mt-dec-do-not-modify-thr-in_size-in-the-worker-thread.patch
# https://github.com/tukaani-project/xz/commit/77bc2d6f3b6e1506c122b03cff49c902219869e3
Patch0005: 0005-liblzma-add-assertions-to-lzma_bufcpy.patch

BuildRequires:  make gcc perl sed
Requires:       grep

%description
XZ Utils are an attempt to make LZMA compression easy to use on free (as in
freedom) operating systems. This is achieved by providing tools and libraries
which are similar to use than the equivalents of the most popular existing
compression algorithms.

LZMA is a general purpose compression algorithm designed by Igor Pavlov as
part of 7-Zip. It provides high compression ratio while keeping the
decompression speed fast.


%package        libs
Summary:        Libraries for decoding LZMA compression
License:        Public Domain

%description    libs
Libraries for decoding files compressed with LZMA or XZ utils.


%package        static
Summary:        Statically linked library for decoding LZMA compression
License:        Public Domain

%description    static
Statically linked library for decoding files compressed with LZMA or
XZ utils.  Most users should *not* install this.


%package        devel
Summary:        Devel libraries & headers for liblzma
License:        Public Domain
Requires:       %{name}-libs = %{version}-%{release}

%description    devel
Devel libraries and headers for liblzma.

%package        lzma-compat
Summary:        Older LZMA format compatibility binaries
# Just a set of symlinks to 'xz' + two Public Domain binaries.
License:        Public Domain
Requires:       %{name} = %{version}-%{release}
Obsoletes:      lzma < %{version}
Provides:       lzma = %{version}

%description    lzma-compat
The lzma-compat package contains compatibility links for older
commands that deal with the older LZMA format.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install

# xzgrep colorization
%global profiledir %{_sysconfdir}/profile.d
mkdir -p %{buildroot}%{profiledir}
install -p -m644 %{SOURCE1} %{SOURCE2} %{buildroot}%{profiledir}

%find_lang %name
%{generate_compatibility_deps}

%check
LD_LIBRARY_PATH=$PWD/src/liblzma/.libs %make_build check

%files -f %{name}.lang
%license COPYING*
%doc %{_pkgdocdir}
%exclude %_pkgdocdir/examples*
%{_bindir}/*xz*
%{abidir}/*xz*-option.list
%{_mandir}/man1/*xz*
%lang(de) %{_mandir}/de/man1/*xz*
%lang(fr) %{_mandir}/fr/man1/*xz*
%lang(ko) %{_mandir}/ko/man1/*xz*
%lang(ro) %{_mandir}/ro/man1/*xz*
%lang(pt_BR) %{_mandir}/pt_BR/man1/*xz*
%lang(uk) %{_mandir}/uk/man1/*xz*
%{profiledir}/*

%files libs
%dir %{abidir}
%license COPYING
%{_libdir}/lib*.so.5*
%{abidir}/lib*.dump

%files static
%license COPYING
%{_libdir}/liblzma.a

%files devel
%dir %{_includedir}/lzma
%{_includedir}/lzma/*.h
%{_includedir}/lzma.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/liblzma.pc
%doc %_pkgdocdir/examples*

%files lzma-compat
%{_bindir}/*lz*
%{abidir}/*lz*-option.list
%{_mandir}/man1/*lz*
%lang(de) %{_mandir}/de/man1/*lz*
%lang(fr) %{_mandir}/fr/man1/*lz*
%lang(ko) %{_mandir}/ko/man1/*lz*
%lang(pt_BR) %{_mandir}/pt_BR/man1/*lz*
%lang(ro) %{_mandir}/ro/man1/*lz*
%lang(uk) %{_mandir}/uk/man1/*lz*

%changelog
* Wed Apr 09 2025 tomcruiseqi <qizengtian@inspur.com> - 5.4.7-2
- Fix CVE-2025-31115

* Wed Aug 21 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.4.7-1
- New version 5.4.7

* Thu Aug 03 2023 Funda Wang <fundawang@yeah.net> - 5.4.4-1
- New version 5.4.4

* Fri May 05 2023 Funda Wang <fundawang@yeah.net> - 5.4.3-1
- New version 5.4.3

* Sun Mar 19 2023 Funda Wang <fundawang@yeah.net> - 5.4.2-1
- New version 5.4.2

* Thu Jan 12 2023 Funda Wang <fundawang@yeah.net> - 5.4.1-1
- New version 5.4.1

* Thu Dec 15 2022 Funda Wang <fundawang@yeah.net> - 5.4.0-1
- New version 5.4.0

* Thu Dec 1 2022 Funda Wang <fundawang@yeah.net> - 5.2.9-1
- New version 5.2.9

* Mon Nov 14 2022 Funda Wang <fundawang@yeah.net> - 5.2.8-1
- New version 5.2.8

* Fri Oct 14 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 5.2.6-3
- optimise spec file

* Wed Oct 12 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.2.6-2
- add abi & api

* Thu Sep 22 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.2.6-1
- update to 5.2.6

* Mon Mar  7 2022 forrest_ly <flin@linux.alibaba.com> - 5.2.5-1
- Init for Anolis OS 23 
